@@ -254,43 +254,41 @@ struct nd_opt_6co {
 struct Interface *readin_config(char const *fname);
 
 /* radvd.c */
-int disable_ipv6_autoconfig(char const *iface);
 
 /* timer.c */
-struct timespec next_timespec(double next);
-int64_t timespecdiff(struct timespec const *a, struct timespec const *b);
-uint64_t next_time_msec(struct Interface const *iface);
 int expired(struct Interface const *iface);
+int64_t timespecdiff(struct timespec const *a, struct timespec const *b);
+struct timespec next_timespec(double next);
+uint64_t next_time_msec(struct Interface const *iface);
 
 /* device.c */
-int update_device_index(struct Interface *iface);
-int update_device_info(int sock, struct Interface *);
 int check_device(int sock, struct Interface *);
-int setup_linklocal_addr(struct Interface *);
-int setup_allrouters_membership(int sock, struct Interface *);
-int setup_linklocal_addr(struct Interface *iface);
+int check_ip6_forwarding(void);
 int get_v4addr(const char *, unsigned int *);
-int set_interface_linkmtu(const char *, uint32_t);
 int set_interface_curhlim(const char *, uint8_t);
+int set_interface_linkmtu(const char *, uint32_t);
 int set_interface_reachtime(const char *, uint32_t);
 int set_interface_retranstimer(const char *, uint32_t);
-int set_interface_autoconfig(const char *, uint32_t);
-int check_ip6_forwarding(void);
+int setup_allrouters_membership(int sock, struct Interface *);
+int setup_linklocal_addr(struct Interface *);
+int setup_linklocal_addr(struct Interface *iface);
+int update_device_index(struct Interface *iface);
+int update_device_info(int sock, struct Interface *);
 
 /* interface.c */
-void iface_init_defaults(struct Interface *);
-void prefix_init_defaults(struct AdvPrefix *);
-void route_init_defaults(struct AdvRoute *, struct Interface *);
-void rdnss_init_defaults(struct AdvRDNSS *, struct Interface *);
-void dnssl_init_defaults(struct AdvDNSSL *, struct Interface *);
 int check_iface(struct Interface *);
-void touch_iface(struct Interface * iface);
 int setup_iface(int sock, struct Interface *iface);
-void free_ifaces(struct Interface *ifaces);
 struct Interface *find_iface_by_index(struct Interface *iface, int index);
 struct Interface *find_iface_by_time(struct Interface *iface_list);
+void dnssl_init_defaults(struct AdvDNSSL *, struct Interface *);
 void for_each_iface(struct Interface *ifaces, void (*foo) (struct Interface * iface, void *), void *data);
+void free_ifaces(struct Interface *ifaces);
+void iface_init_defaults(struct Interface *);
+void prefix_init_defaults(struct AdvPrefix *);
+void rdnss_init_defaults(struct AdvRDNSS *, struct Interface *);
 void reschedule_iface(struct Interface *iface, double next);
+void route_init_defaults(struct AdvRoute *, struct Interface *);
+void touch_iface(struct Interface * iface);
 
 /* socket.c */
 int open_icmpv6_socket(void);
@@ -307,23 +305,23 @@ int recv_rs_ra(int sock, unsigned char *, struct sockaddr_in6 *, struct in6_pkti
 /* util.c */
 char * strdupf(char const * format, ...) __attribute__ ((format(printf, 1, 2)));
 double rand_between(double, double);
-void addrtostr(struct in6_addr *, char *, size_t);
-int check_rdnss_presence(struct AdvRDNSS *, struct in6_addr *);
 int check_dnssl_presence(struct AdvDNSSL *, const char *);
+int check_rdnss_presence(struct AdvRDNSS *, struct in6_addr *);
+size_t safe_buffer_append(struct safe_buffer * sb, void const * m, size_t count);
+size_t safe_buffer_pad(struct safe_buffer * sb, size_t count);
 ssize_t readn(int fd, void *buf, size_t count);
 ssize_t writen(int fd, const void *buf, size_t count);
 struct safe_buffer * new_safe_buffer(void);
+void addrtostr(struct in6_addr *, char *, size_t);
 void safe_buffer_free(struct safe_buffer * sb);
-size_t safe_buffer_pad(struct safe_buffer * sb, size_t count);
-size_t safe_buffer_append(struct safe_buffer * sb, void const * m, size_t count);
 
 /* privsep.c */
-int privsep_init(void*, void*);
-int privsep_interface_linkmtu(const char *iface, uint32_t mtu);
 int privsep_interface_curhlim(const char *iface, uint32_t hlim);
+int privsep_interface_linkmtu(const char *iface, uint32_t mtu);
 int privsep_interface_reachtime(const char *iface, uint32_t rtime);
 int privsep_interface_retranstimer(const char *iface, uint32_t rettimer);
-int privsep_interface_autoconfig(const char *iface, uint32_t newvalue);
+void privsep_init(int);
+void privsep_set_write_fd(int);
 
 /*
  * compat hacks in case libc and kernel get out of sync:
